(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     47136,       1302]
NotebookOptionsPosition[     39983,       1177]
NotebookOutlinePosition[     41091,       1218]
CellTagsIndexPosition[     41048,       1215]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Chapter 1, Section 1.7, Figure 1.8", "Section",
 PageWidth:>
  WindowWidth,ExpressionUUID->"2e046fd1-02bf-471e-bed0-2aa608f175b2"],

Cell["\<\
Here we start the input of data on the various bodies to be included.  First \
we input the orbital periods of the planets in days (calculated using \
Kepler's third law) followed by their names.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"2a07afad-9c27-4c77-9971-06fcbe97d0fa"],

Cell["\<\
planets = 365.25*
({0.38710353, 0.7233074, 1.00001161, 1.52371069,
  5.21021558, 9.53807012, 19.183302, 30.055144,
  39.53758}^(3/2));\
\>", "Input",
 PageWidth:>WindowWidth,
 AspectRatioFixed->True,
 CellLabel->"In[1]:=",ExpressionUUID->"66fd2450-98bf-4d4e-bed2-892797d75ae0"],

Cell["\<\
planetsnames = {\"Mercury\", \"Venus\", \"Earth\", \"Mars\",
\"Jupiter\", \"Saturn\", \"Uranus\", \"Neptune\", \"Pluto\"};\
\>", "Input",
 PageWidth:>WindowWidth,
 AspectRatioFixed->True,
 CellLabel->"In[2]:=",ExpressionUUID->"a706c228-4c86-4c49-bbde-2cb171c07558"],

Cell["Now do the same for the jovian system ...", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"62d4b19b-7a6e-4f25-96a4-8590224392f7"],

Cell["\<\
jupiter = 
 {0.49817905, 1.769137786, 3.551181041, 7.15455296, 
  16.6890184};\
\>", "Input",
 PageWidth:>WindowWidth,
 AspectRatioFixed->True,
 CellLabel->"In[3]:=",ExpressionUUID->"ae06e143-0605-481b-8e25-113929c3a0e3"],

Cell["\<\
jupiternames = {\"Amalthea\", \"Io\", \"Europa\", \"Ganymede\",
\"Callisto\"};\
\>", "Input",
 PageWidth:>WindowWidth,
 AspectRatioFixed->True,
 CellLabel->"In[4]:=",ExpressionUUID->"f0fe5fb2-21ec-4743-9ec8-2a1d0ca7357a"],

Cell["... the saturnian system ...", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"01d63a53-4d49-4c57-9b24-6ef579cac1ed"],

Cell["\<\
saturn = 
 {0.942421813, 1.370217855, 1.887802160, 2.736914742,
  4.517500436, 15.94542068, 21.2766088, 79.3301825};\
\>", "Input",
 PageWidth:>WindowWidth,
 AspectRatioFixed->True,
 CellLabel->"In[5]:=",ExpressionUUID->"ba2ea064-311d-4297-ba35-05f9f7eebc56"],

Cell["\<\
saturnnames = {\"Mimas\", \"Enceladus\", \"Tethys\", \"Dione\",
\"Rhea\", \"Titan\", \"Hyperion\", \"Iapetus\"};\
\>", "Input",
 PageWidth:>WindowWidth,
 AspectRatioFixed->True,
 CellLabel->"In[6]:=",ExpressionUUID->"fd7605ee-b33e-45a5-acef-ae3b8463e4fb"],

Cell["... the uranian system ...", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"baa27e18-316d-48b7-890c-c790af2fc2a2"],

Cell["\<\
uranus = 
 {1.41347925, 2.52037935, 4.1441772, 8.7058717,
  13.4632389};\
\>", "Input",
 PageWidth:>WindowWidth,
 AspectRatioFixed->True,
 CellLabel->"In[7]:=",ExpressionUUID->"4aa19074-229b-4c7e-ae4e-c15a78fb01e2"],

Cell["\<\
uranusnames = {\"Miranda\", \"Ariel\", \"Umbriel\",
\"Titania\", \"Oberon\"}; \
\>", "Input",
 PageWidth:>WindowWidth,
 AspectRatioFixed->True,
 CellLabel->"In[8]:=",ExpressionUUID->"bb428c6f-70f1-4692-9112-cd699b8d864d"],

Cell["... and the neptunian system ...", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"9de56b14-6c4d-4c95-9d03-d294beec690e"],

Cell["\<\
neptune =
{5.8768541, 360.13619};\
\>", "Input",
 PageWidth:>WindowWidth,
 AspectRatioFixed->True,
 CellLabel->"In[9]:=",ExpressionUUID->"0faeffc2-181a-4f6e-8391-bb1d7987d08f"],

Cell["neptunenames = {\"Triton\", \"Nereid\"};", "Input",
 PageWidth:>WindowWidth,
 AspectRatioFixed->True,
 CellLabel->"In[10]:=",ExpressionUUID->"eb869435-4f7b-4c8e-bc0d-3c0c8f74e223"],

Cell[TextData[{
 StyleBox["Set up a list containing the rationals that correspond to \
first-order commensurabilities of the form ", "Text"],
 StyleBox["p/", "Text",
  FontSlant->"Italic"],
 StyleBox["(", "Text"],
 StyleBox["p", "Text",
  FontSlant->"Italic"],
 StyleBox["+1), with ", "Text"],
 StyleBox["p", "Text",
  FontSlant->"Italic"],
 StyleBox["\[LessEqual]100 and ", "Text"],
 Cell[BoxData[
  FormBox[
   FractionBox["1", "3"], TraditionalForm]],ExpressionUUID->
  "1d0be7f5-e668-41bd-aeeb-5cf01f2c5fec"],
 "added at the start.  This will form the set of rationals which will bound a \
ratio of orbital periods."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"34cdcecf-a898-488c-b050-9d5221c166e0"],

Cell[CellGroupData[{

Cell["first = Join[{1/3},Table[i/(i+1), {i,1,100}]]", "Input",
 PageWidth:>WindowWidth,
 AspectRatioFixed->True,
 CellLabel->"In[11]:=",ExpressionUUID->"e6b02b7f-38c8-4880-a4e4-d5b4f8a5dc1b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", "3"], ",", 
   FractionBox["1", "2"], ",", 
   FractionBox["2", "3"], ",", 
   FractionBox["3", "4"], ",", 
   FractionBox["4", "5"], ",", 
   FractionBox["5", "6"], ",", 
   FractionBox["6", "7"], ",", 
   FractionBox["7", "8"], ",", 
   FractionBox["8", "9"], ",", 
   FractionBox["9", "10"], ",", 
   FractionBox["10", "11"], ",", 
   FractionBox["11", "12"], ",", 
   FractionBox["12", "13"], ",", 
   FractionBox["13", "14"], ",", 
   FractionBox["14", "15"], ",", 
   FractionBox["15", "16"], ",", 
   FractionBox["16", "17"], ",", 
   FractionBox["17", "18"], ",", 
   FractionBox["18", "19"], ",", 
   FractionBox["19", "20"], ",", 
   FractionBox["20", "21"], ",", 
   FractionBox["21", "22"], ",", 
   FractionBox["22", "23"], ",", 
   FractionBox["23", "24"], ",", 
   FractionBox["24", "25"], ",", 
   FractionBox["25", "26"], ",", 
   FractionBox["26", "27"], ",", 
   FractionBox["27", "28"], ",", 
   FractionBox["28", "29"], ",", 
   FractionBox["29", "30"], ",", 
   FractionBox["30", "31"], ",", 
   FractionBox["31", "32"], ",", 
   FractionBox["32", "33"], ",", 
   FractionBox["33", "34"], ",", 
   FractionBox["34", "35"], ",", 
   FractionBox["35", "36"], ",", 
   FractionBox["36", "37"], ",", 
   FractionBox["37", "38"], ",", 
   FractionBox["38", "39"], ",", 
   FractionBox["39", "40"], ",", 
   FractionBox["40", "41"], ",", 
   FractionBox["41", "42"], ",", 
   FractionBox["42", "43"], ",", 
   FractionBox["43", "44"], ",", 
   FractionBox["44", "45"], ",", 
   FractionBox["45", "46"], ",", 
   FractionBox["46", "47"], ",", 
   FractionBox["47", "48"], ",", 
   FractionBox["48", "49"], ",", 
   FractionBox["49", "50"], ",", 
   FractionBox["50", "51"], ",", 
   FractionBox["51", "52"], ",", 
   FractionBox["52", "53"], ",", 
   FractionBox["53", "54"], ",", 
   FractionBox["54", "55"], ",", 
   FractionBox["55", "56"], ",", 
   FractionBox["56", "57"], ",", 
   FractionBox["57", "58"], ",", 
   FractionBox["58", "59"], ",", 
   FractionBox["59", "60"], ",", 
   FractionBox["60", "61"], ",", 
   FractionBox["61", "62"], ",", 
   FractionBox["62", "63"], ",", 
   FractionBox["63", "64"], ",", 
   FractionBox["64", "65"], ",", 
   FractionBox["65", "66"], ",", 
   FractionBox["66", "67"], ",", 
   FractionBox["67", "68"], ",", 
   FractionBox["68", "69"], ",", 
   FractionBox["69", "70"], ",", 
   FractionBox["70", "71"], ",", 
   FractionBox["71", "72"], ",", 
   FractionBox["72", "73"], ",", 
   FractionBox["73", "74"], ",", 
   FractionBox["74", "75"], ",", 
   FractionBox["75", "76"], ",", 
   FractionBox["76", "77"], ",", 
   FractionBox["77", "78"], ",", 
   FractionBox["78", "79"], ",", 
   FractionBox["79", "80"], ",", 
   FractionBox["80", "81"], ",", 
   FractionBox["81", "82"], ",", 
   FractionBox["82", "83"], ",", 
   FractionBox["83", "84"], ",", 
   FractionBox["84", "85"], ",", 
   FractionBox["85", "86"], ",", 
   FractionBox["86", "87"], ",", 
   FractionBox["87", "88"], ",", 
   FractionBox["88", "89"], ",", 
   FractionBox["89", "90"], ",", 
   FractionBox["90", "91"], ",", 
   FractionBox["91", "92"], ",", 
   FractionBox["92", "93"], ",", 
   FractionBox["93", "94"], ",", 
   FractionBox["94", "95"], ",", 
   FractionBox["95", "96"], ",", 
   FractionBox["96", "97"], ",", 
   FractionBox["97", "98"], ",", 
   FractionBox["98", "99"], ",", 
   FractionBox["99", "100"], ",", 
   FractionBox["100", "101"]}], "}"}]], "Output",
 CellChangeTimes->{3.811158910249011*^9, 3.811159036499073*^9, 
  3.811160809208398*^9},
 CellLabel->"Out[11]=",ExpressionUUID->"7f6ad3c5-4922-4724-a913-d752b770f1ca"]
}, Open  ]],

Cell[TextData[{
 "Define a function ",
 StyleBox["ratios", "Input"],
 " which will create a list of ratios of periods >",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox["1", "3"], "+", 
    RowBox[{
     FractionBox["1", "12"], "."}]}], TraditionalForm]],ExpressionUUID->
  "71371470-5154-4584-a850-60e86407a976"],
 " The ",
 Cell[BoxData[
  FormBox[
   FractionBox["1", "12"], TraditionalForm]],ExpressionUUID->
  "0579637f-fcf1-4413-8e69-21ad701e31c1"],
 "is half of the \"separation\" between ",
 Cell[BoxData[
  FormBox[
   FractionBox["1", "3"], TraditionalForm]],ExpressionUUID->
  "2d07f376-17dc-408a-ad10-940235d005ca"],
 "and ",
 Cell[BoxData[
  FormBox[
   FractionBox["1", "2"], TraditionalForm]],ExpressionUUID->
  "aef11356-1ecc-4e72-b99f-8f49e62c476b"],
 ", the first two rationals in ",
 StyleBox["first", "Input"],
 "."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ff33bb00-2d91-4ec1-84eb-8e57445efdbd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ratios", "[", 
   RowBox[{"data_List", ",", " ", "name_List"}], "]"}], " ", ":=", "\n", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"len", "=", 
       RowBox[{"Length", "[", "data", "]"}]}], ",", " ", "temp1", ",", " ", 
      "temp2"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"temp1", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"name", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"name", "[", 
           RowBox[{"[", "j", "]"}], "]"}], ",", 
          RowBox[{
           RowBox[{"data", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "/", 
           RowBox[{"data", "[", 
            RowBox[{"[", "j", "]"}], "]"}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"len", "-", "1"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", 
          RowBox[{"i", "+", "1"}], ",", "len"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"temp2", "=", 
      RowBox[{"FlattenAt", "[", 
       RowBox[{"temp1", ",", " ", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", "i", "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"len", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}], ";", 
     RowBox[{"Select", "[", 
      RowBox[{"temp2", ",", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "3", "]"}], "]"}], ">", 
          RowBox[{
           RowBox[{"1", "/", "3"}], "+", 
           RowBox[{"1", "/", "12"}]}]}], ")"}], "&"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 PageWidth:>WindowWidth,
 CellLabel->"In[12]:=",ExpressionUUID->"63b2dee2-1a80-4acf-8b64-837a38ea3ce3"],

Cell["\<\
Now create the relevant ratios for the planets and all the satellite systems.\
\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ea7134eb-b4e9-4cee-bbac-161cb3ff335f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"prat", "=", 
  RowBox[{"ratios", "[", 
   RowBox[{"planets", ",", " ", "planetsnames"}], "]"}]}]], "Input",
 PageWidth:>WindowWidth,
 CellLabel->"In[13]:=",ExpressionUUID->"091e7ab0-e695-4395-af2e-f1bd302830cc"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"Venus\"\>", ",", "\<\"Earth\"\>", ",", 
     "0.6151440097830618`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Earth\"\>", ",", "\<\"Mars\"\>", ",", 
     "0.5316842451344407`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Uranus\"\>", ",", "\<\"Neptune\"\>", ",", 
     "0.5099256124519637`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Neptune\"\>", ",", "\<\"Pluto\"\>", ",", 
     "0.6627703847265115`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.811158910280718*^9, {3.811159082268511*^9, 3.811159091802216*^9}, 
   3.811160809249625*^9},
 CellLabel->"Out[13]=",ExpressionUUID->"eb44f92f-9cad-4920-86a8-9f81143c6e1e"]
}, Open  ]],

Cell[CellGroupData[{

Cell["jrat=ratios[jupiter, jupiternames]", "Input",
 PageWidth:>WindowWidth,
 AspectRatioFixed->True,
 CellLabel->"In[14]:=",ExpressionUUID->"12dbef65-1043-4ca6-8c56-45dee671534c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"Io\"\>", ",", "\<\"Europa\"\>", ",", "0.4981829328255866`"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Europa\"\>", ",", "\<\"Ganymede\"\>", ",", 
     "0.49635261082755333`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Ganymede\"\>", ",", "\<\"Callisto\"\>", ",", 
     "0.42869824866392386`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.811158910310287*^9, {3.811159104246169*^9, 3.811159108997096*^9}, 
   3.811160809288419*^9},
 CellLabel->"Out[14]=",ExpressionUUID->"b054f0aa-0633-4320-abf5-1c6be6ddcfc5"]
}, Open  ]],

Cell[CellGroupData[{

Cell["srat=ratios[saturn, saturnnames]", "Input",
 PageWidth:>WindowWidth,
 AspectRatioFixed->True,
 CellLabel->"In[15]:=",ExpressionUUID->"b4e1a9e0-9fa7-48eb-b2fd-89bb4e956a84"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"Mimas\"\>", ",", "\<\"Enceladus\"\>", ",", 
     "0.6877897624535042`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Mimas\"\>", ",", "\<\"Tethys\"\>", ",", 
     "0.4992164078252777`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Enceladus\"\>", ",", "\<\"Tethys\"\>", ",", 
     "0.7258270405835324`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Enceladus\"\>", ",", "\<\"Dione\"\>", ",", 
     "0.5006432366975061`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Tethys\"\>", ",", "\<\"Dione\"\>", ",", 
     "0.6897555598025275`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Tethys\"\>", ",", "\<\"Rhea\"\>", ",", 
     "0.4178864367020506`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Dione\"\>", ",", "\<\"Rhea\"\>", ",", 
     "0.6058471450693182`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Titan\"\>", ",", "\<\"Hyperion\"\>", ",", 
     "0.7494343121071061`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.811158910316741*^9, 3.811159112215414*^9, 
  3.81116080929459*^9},
 CellLabel->"Out[15]=",ExpressionUUID->"de27dfbd-ae18-4647-ba6b-b5502f5f92e9"]
}, Open  ]],

Cell[CellGroupData[{

Cell["urat=ratios[uranus, uranusnames]", "Input",
 PageWidth:>WindowWidth,
 AspectRatioFixed->True,
 CellLabel->"In[16]:=",ExpressionUUID->"82abcbb4-d4b6-4463-86d7-01389f35a3d3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"Miranda\"\>", ",", "\<\"Ariel\"\>", ",", 
     "0.5608200408402807`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Ariel\"\>", ",", "\<\"Umbriel\"\>", ",", 
     "0.6081736442157928`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Umbriel\"\>", ",", "\<\"Titania\"\>", ",", 
     "0.47602093653642974`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Titania\"\>", ",", "\<\"Oberon\"\>", ",", 
     "0.6466402152308238`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8111589103452797`*^9, 3.811159117223287*^9, 
  3.811160809323187*^9},
 CellLabel->"Out[16]=",ExpressionUUID->"4c41aea0-1c7b-45e5-9090-2862c2a7cc5e"]
}, Open  ]],

Cell[CellGroupData[{

Cell["nrat=ratios[neptune, neptunenames]", "Input",
 PageWidth:>WindowWidth,
 AspectRatioFixed->True,
 CellLabel->"In[17]:=",ExpressionUUID->"2b2963a8-4f20-4084-9858-22b0e9d26e10"],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output",
 CellChangeTimes->{3.8111589103512707`*^9, 3.811159123270164*^9, 
  3.811160809329236*^9},
 CellLabel->"Out[17]=",ExpressionUUID->"4b15edb5-1d9e-489e-ad59-fbb90da640b2"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Define a function ", "Text"],
 StyleBox["nearest", "Input"],
 StyleBox[" that will find the two rationals from ", "Text"],
 StyleBox["first", "Input"],
 StyleBox[" that bound the each of the ratios of periods supllied.  ", "Text"],
 StyleBox["nearest", "Input"],
 StyleBox[" uses a continued fraction expansion of the ratio to find the \
closest rational from the list.  ", "Text"]
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8111591442356157`*^9, 3.811159146920529*^9}, 
   3.811160779557732*^9},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"61b0fe8b-dc67-4ad3-bbe4-20ee61d6f564"],

Cell["\<\
nearest[vlist_List] :=
Module[{closest,pos,next},
closest = 
Map[
(Intersection[
Convergents[
ContinuedFraction[#,4]],
   first][[1]])&,
 vlist];
pos = Map[Position[first,#][[1,1]]&,closest];
next = 
Table[
  If[vlist[[i]] < closest[[i]], 
     first[[pos[[i]]-1]], 
     first[[pos[[i]]+1]]], {i,Length[vlist]}];
Map[Sort,Transpose[{closest,next}]]
]\
\>", "Input",
 CellChangeTimes->{{3.811160619375894*^9, 3.811160622228076*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"6f8e7244-168c-4154-866f-7d554694c83c"],

Cell[TextData[{
 "Define a function ",
 StyleBox["ccalc", "Input"],
 " to calculate the value of ",
 StyleBox["c",
  FontSlant->"Italic"],
 " (see Eqs.(1.16)-(1.19)), a measure of the normalised \"distance\" to the \
nearest first order resonance."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8111603924692993`*^9, 3.811160395010324*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"d5793148-6430-41d8-b67d-f17b1284f382"],

Cell["\<\
ccalc[data_List, names_List] :=
Module[{temp,rlist,nlist,upper,lower,a,b,c},
 temp = Transpose[ratios[data, names]];
 rlist = temp[[3]];
 nlist = nearest[rlist];
 upper = Transpose[nlist][[2]];
 lower = Transpose[nlist][[1]];
 a = (rlist-lower)/(upper-lower);
 b = Map[If[# <= 1/2, 0, 1]&, a];
 c = 2*Pi*(a-b);
 Transpose[{temp[[1]], temp[[2]], rlist, nlist, c}]
 ]\
\>", "Input",
 PageWidth:>WindowWidth,
 AspectRatioFixed->True,
 CellLabel->"In[19]:=",ExpressionUUID->"d6100c74-ec82-4c2d-8524-4996f6f2b59d"],

Cell[TextData[{
 "For example, here are the ratio of orbital periods, the bounding rationals \
and the values of ",
 StyleBox["c",
  FontSlant->"Italic"],
 " for valid pairs of planets."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"13de1944-42c1-444f-ac66-7421f41ce1e8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ccalc", "[", 
  RowBox[{"planets", ",", " ", "planetsnames"}], "]"}]], "Input",
 PageWidth:>WindowWidth,
 CellLabel->"In[20]:=",ExpressionUUID->"4e36306e-f95a-47e7-ba2e-671f2ff82360"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"Venus\"\>", ",", "\<\"Earth\"\>", ",", "0.6151440097830618`",
      ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", 
       FractionBox["2", "3"]}], "}"}], ",", 
     RowBox[{"-", "1.9423584043075266`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Earth\"\>", ",", "\<\"Mars\"\>", ",", "0.5316842451344407`", 
     ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", 
       FractionBox["2", "3"]}], "}"}], ",", "1.1944679009867638`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Uranus\"\>", ",", "\<\"Neptune\"\>", ",", 
     "0.5099256124519637`", ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", 
       FractionBox["2", "3"]}], "}"}], ",", "0.37418677393762095`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Neptune\"\>", ",", "\<\"Pluto\"\>", ",", 
     "0.6627703847265115`", ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", 
       FractionBox["2", "3"]}], "}"}], ",", 
     RowBox[{"-", "0.1468863686340724`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8111589104268417`*^9, 3.8111606393255796`*^9, 
  3.811160809341601*^9},
 CellLabel->"Out[20]=",ExpressionUUID->"5a783ee5-1245-4aea-879c-f1e8d2998328"]
}, Open  ]],

Cell["\<\
Create a list of such results for all valid planet and satellite pairs.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"b465bd8e-819c-4c87-985c-1df8e2fb313b"],

Cell[CellGroupData[{

Cell["\<\
clist = 
Union[ccalc[planets, planetsnames],ccalc[jupiter, jupiternames],ccalc[saturn, \
saturnnames],
      ccalc[uranus, uranusnames]]\
\>", "Input",
 PageWidth:>WindowWidth,
 AspectRatioFixed->True,
 CellLabel->"In[21]:=",ExpressionUUID->"0424cd75-bcb0-49db-82b1-0dc90fe2de0c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"Ariel\"\>", ",", "\<\"Umbriel\"\>", ",", 
     "0.6081736442157928`", ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", 
       FractionBox["2", "3"]}], "}"}], ",", 
     RowBox[{"-", "2.2051349954151385`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Dione\"\>", ",", "\<\"Rhea\"\>", ",", "0.6058471450693182`", 
     ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", 
       FractionBox["2", "3"]}], "}"}], ",", 
     RowBox[{"-", "2.2928419469409067`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Earth\"\>", ",", "\<\"Mars\"\>", ",", "0.5316842451344407`", 
     ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", 
       FractionBox["2", "3"]}], "}"}], ",", "1.1944679009867638`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Enceladus\"\>", ",", "\<\"Dione\"\>", ",", 
     "0.5006432366975061`", ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", 
       FractionBox["2", "3"]}], "}"}], ",", "0.024249452200854282`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Enceladus\"\>", ",", "\<\"Tethys\"\>", ",", 
     "0.7258270405835324`", ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["2", "3"], ",", 
       FractionBox["3", "4"]}], "}"}], ",", 
     RowBox[{"-", "1.8225982012391673`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Europa\"\>", ",", "\<\"Ganymede\"\>", ",", 
     "0.49635261082755333`", ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "3"], ",", 
       FractionBox["1", "2"]}], "}"}], ",", 
     RowBox[{"-", "0.13750333234729623`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Ganymede\"\>", ",", "\<\"Callisto\"\>", ",", 
     "0.42869824866392386`", ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "3"], ",", 
       FractionBox["1", "2"]}], "}"}], ",", 
     RowBox[{"-", "2.6880126982260353`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Io\"\>", ",", "\<\"Europa\"\>", ",", "0.4981829328255866`", 
     ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "3"], ",", 
       FractionBox["1", "2"]}], "}"}], ",", 
     RowBox[{"-", "0.06850181863459409`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Mimas\"\>", ",", "\<\"Enceladus\"\>", ",", 
     "0.6877897624535042`", ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["2", "3"], ",", 
       FractionBox["3", "4"]}], "}"}], ",", "1.5926439010800586`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Mimas\"\>", ",", "\<\"Tethys\"\>", ",", 
     "0.4992164078252777`", ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "3"], ",", 
       FractionBox["1", "2"]}], "}"}], ",", 
     RowBox[{"-", "0.02954072903421532`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Miranda\"\>", ",", "\<\"Ariel\"\>", ",", 
     "0.5608200408402807`", ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", 
       FractionBox["2", "3"]}], "}"}], ",", "2.2928615219382844`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Neptune\"\>", ",", "\<\"Pluto\"\>", ",", 
     "0.6627703847265115`", ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", 
       FractionBox["2", "3"]}], "}"}], ",", 
     RowBox[{"-", "0.1468863686340724`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Tethys\"\>", ",", "\<\"Dione\"\>", ",", 
     "0.6897555598025275`", ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["2", "3"], ",", 
       FractionBox["3", "4"]}], "}"}], ",", "1.7408615293233638`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Tethys\"\>", ",", "\<\"Rhea\"\>", ",", "0.4178864367020506`",
      ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "3"], ",", 
       FractionBox["1", "2"]}], "}"}], ",", 
     RowBox[{"-", "3.0956084066030183`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Titan\"\>", ",", "\<\"Hyperion\"\>", ",", 
     "0.7494343121071061`", ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["2", "3"], ",", 
       FractionBox["3", "4"]}], "}"}], ",", 
     RowBox[{"-", "0.04265186228496171`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Titania\"\>", ",", "\<\"Oberon\"\>", ",", 
     "0.6466402152308238`", ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", 
       FractionBox["2", "3"]}], "}"}], ",", 
     RowBox[{"-", "0.7549794324997997`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Umbriel\"\>", ",", "\<\"Titania\"\>", ",", 
     "0.47602093653642974`", ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "3"], ",", 
       FractionBox["1", "2"]}], "}"}], ",", 
     RowBox[{"-", "0.9039893954053883`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Uranus\"\>", ",", "\<\"Neptune\"\>", ",", 
     "0.5099256124519637`", ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", 
       FractionBox["2", "3"]}], "}"}], ",", "0.37418677393762095`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Venus\"\>", ",", "\<\"Earth\"\>", ",", "0.6151440097830618`",
      ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", 
       FractionBox["2", "3"]}], "}"}], ",", 
     RowBox[{"-", "1.9423584043075266`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8111589105307007`*^9, 3.811160645334011*^9, 
  3.811160809382257*^9},
 CellLabel->"Out[21]=",ExpressionUUID->"a6908933-d9bf-4eed-8836-c567b60eb6ad"]
}, Open  ]],

Cell[TextData[{
 "Order this list by taking the absolute value of ",
 StyleBox["c",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"54c9009d-4447-40a6-b051-bc3b4b875f66"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"orderedclist", "=", 
  RowBox[{"Sort", "[", 
   RowBox[{"clist", ",", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Abs", "[", 
        RowBox[{"#2", "[", 
         RowBox[{"[", "5", "]"}], "]"}], "]"}], " ", ">", " ", 
       RowBox[{"Abs", "[", 
        RowBox[{"#1", "[", 
         RowBox[{"[", "5", "]"}], "]"}], "]"}]}], ")"}], "&"}]}], 
   "]"}]}]], "Input",
 PageWidth:>WindowWidth,
 CellLabel->"In[22]:=",ExpressionUUID->"640fc8ac-961b-4b7d-86de-9ce1c124c8fc"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"Enceladus\"\>", ",", "\<\"Dione\"\>", ",", 
     "0.5006432366975061`", ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", 
       FractionBox["2", "3"]}], "}"}], ",", "0.024249452200854282`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Mimas\"\>", ",", "\<\"Tethys\"\>", ",", 
     "0.4992164078252777`", ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "3"], ",", 
       FractionBox["1", "2"]}], "}"}], ",", 
     RowBox[{"-", "0.02954072903421532`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Titan\"\>", ",", "\<\"Hyperion\"\>", ",", 
     "0.7494343121071061`", ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["2", "3"], ",", 
       FractionBox["3", "4"]}], "}"}], ",", 
     RowBox[{"-", "0.04265186228496171`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Io\"\>", ",", "\<\"Europa\"\>", ",", "0.4981829328255866`", 
     ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "3"], ",", 
       FractionBox["1", "2"]}], "}"}], ",", 
     RowBox[{"-", "0.06850181863459409`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Europa\"\>", ",", "\<\"Ganymede\"\>", ",", 
     "0.49635261082755333`", ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "3"], ",", 
       FractionBox["1", "2"]}], "}"}], ",", 
     RowBox[{"-", "0.13750333234729623`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Neptune\"\>", ",", "\<\"Pluto\"\>", ",", 
     "0.6627703847265115`", ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", 
       FractionBox["2", "3"]}], "}"}], ",", 
     RowBox[{"-", "0.1468863686340724`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Uranus\"\>", ",", "\<\"Neptune\"\>", ",", 
     "0.5099256124519637`", ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", 
       FractionBox["2", "3"]}], "}"}], ",", "0.37418677393762095`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Titania\"\>", ",", "\<\"Oberon\"\>", ",", 
     "0.6466402152308238`", ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", 
       FractionBox["2", "3"]}], "}"}], ",", 
     RowBox[{"-", "0.7549794324997997`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Umbriel\"\>", ",", "\<\"Titania\"\>", ",", 
     "0.47602093653642974`", ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "3"], ",", 
       FractionBox["1", "2"]}], "}"}], ",", 
     RowBox[{"-", "0.9039893954053883`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Earth\"\>", ",", "\<\"Mars\"\>", ",", "0.5316842451344407`", 
     ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", 
       FractionBox["2", "3"]}], "}"}], ",", "1.1944679009867638`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Mimas\"\>", ",", "\<\"Enceladus\"\>", ",", 
     "0.6877897624535042`", ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["2", "3"], ",", 
       FractionBox["3", "4"]}], "}"}], ",", "1.5926439010800586`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Tethys\"\>", ",", "\<\"Dione\"\>", ",", 
     "0.6897555598025275`", ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["2", "3"], ",", 
       FractionBox["3", "4"]}], "}"}], ",", "1.7408615293233638`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Enceladus\"\>", ",", "\<\"Tethys\"\>", ",", 
     "0.7258270405835324`", ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["2", "3"], ",", 
       FractionBox["3", "4"]}], "}"}], ",", 
     RowBox[{"-", "1.8225982012391673`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Venus\"\>", ",", "\<\"Earth\"\>", ",", "0.6151440097830618`",
      ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", 
       FractionBox["2", "3"]}], "}"}], ",", 
     RowBox[{"-", "1.9423584043075266`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Ariel\"\>", ",", "\<\"Umbriel\"\>", ",", 
     "0.6081736442157928`", ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", 
       FractionBox["2", "3"]}], "}"}], ",", 
     RowBox[{"-", "2.2051349954151385`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Dione\"\>", ",", "\<\"Rhea\"\>", ",", "0.6058471450693182`", 
     ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", 
       FractionBox["2", "3"]}], "}"}], ",", 
     RowBox[{"-", "2.2928419469409067`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Miranda\"\>", ",", "\<\"Ariel\"\>", ",", 
     "0.5608200408402807`", ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", 
       FractionBox["2", "3"]}], "}"}], ",", "2.2928615219382844`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Ganymede\"\>", ",", "\<\"Callisto\"\>", ",", 
     "0.42869824866392386`", ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "3"], ",", 
       FractionBox["1", "2"]}], "}"}], ",", 
     RowBox[{"-", "2.6880126982260353`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Tethys\"\>", ",", "\<\"Rhea\"\>", ",", "0.4178864367020506`",
      ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "3"], ",", 
       FractionBox["1", "2"]}], "}"}], ",", 
     RowBox[{"-", "3.0956084066030183`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.811158910582604*^9, 3.811160655540619*^9, 
  3.8111608093908663`*^9},
 CellLabel->"Out[22]=",ExpressionUUID->"8f5af721-c96d-4be6-9479-356af0403c7a"]
}, Open  ]],

Cell[TextData[{
 "Isolate just the values of ",
 StyleBox["c",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"9271d47b-b849-43f1-bcc4-cf5d6e3d9ce5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"c", " ", "=", " ", 
  RowBox[{
   RowBox[{"Transpose", "[", "orderedclist", "]"}], "[", 
   RowBox[{"[", "5", "]"}], "]"}]}]], "Input",
 PageWidth:>WindowWidth,
 CellLabel->"In[23]:=",ExpressionUUID->"877d84d1-237b-49b1-bbcb-47bc3f789c29"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.024249452200854282`", ",", 
   RowBox[{"-", "0.02954072903421532`"}], ",", 
   RowBox[{"-", "0.04265186228496171`"}], ",", 
   RowBox[{"-", "0.06850181863459409`"}], ",", 
   RowBox[{"-", "0.13750333234729623`"}], ",", 
   RowBox[{"-", "0.1468863686340724`"}], ",", "0.37418677393762095`", ",", 
   RowBox[{"-", "0.7549794324997997`"}], ",", 
   RowBox[{"-", "0.9039893954053883`"}], ",", "1.1944679009867638`", ",", 
   "1.5926439010800586`", ",", "1.7408615293233638`", ",", 
   RowBox[{"-", "1.8225982012391673`"}], ",", 
   RowBox[{"-", "1.9423584043075266`"}], ",", 
   RowBox[{"-", "2.2051349954151385`"}], ",", 
   RowBox[{"-", "2.2928419469409067`"}], ",", "2.2928615219382844`", ",", 
   RowBox[{"-", "2.6880126982260353`"}], ",", 
   RowBox[{"-", "3.0956084066030183`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.811158910663797*^9, 3.811160668973771*^9, 
  3.811160809431883*^9},
 CellLabel->"Out[23]=",ExpressionUUID->"225d17bb-f494-4751-a6f1-ce017a41833a"]
}, Open  ]],

Cell["Note the total number of valid ratios.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"9d868743-e874-41ce-a45a-24131341987c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"n", " ", "=", " ", 
  RowBox[{"Length", "[", "c", "]"}]}]], "Input",
 PageWidth:>WindowWidth,
 CellLabel->"In[24]:=",ExpressionUUID->"09847513-793f-407b-9caa-e04c7749535a"],

Cell[BoxData["19"], "Output",
 CellChangeTimes->{3.811158910689849*^9, 3.81116067455842*^9, 
  3.811160809438686*^9},
 CellLabel->"Out[24]=",ExpressionUUID->"4163bcc5-dcff-4f5c-97d5-1dc3a785ca7d"]
}, Open  ]],

Cell["Create a base line going from 0 to \[Pi] ...", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"56fe806a-458f-401d-8231-4d37a4506c66"],

Cell["baseline=Graphics[{Line[{{0,-0.125},{Pi,-0.125}}]}];", "Input",
 PageWidth:>WindowWidth,
 AspectRatioFixed->True,
 CellLabel->"In[25]:=",ExpressionUUID->"333faf9f-ae10-49d7-9c2b-87df0a655ab3"],

Cell["... and then create a line for each of the pairs.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"74791009-e54c-4e79-ad1b-ae570cc9fcc6"],

Cell["lines=Graphics[Map[Line[{{#,0},{#, 0.25}}]&,Abs[c]]];", "Input",
 PageWidth:>WindowWidth,
 AspectRatioFixed->True,
 CellLabel->"In[26]:=",ExpressionUUID->"3b78f164-12a2-48fe-8d97-cd73b2c77d9a"],

Cell["Now display the main plot ...", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"b07fc449-74a2-47f3-b40c-3ec7bd5ff57e"],

Cell[CellGroupData[{

Cell["\<\
Show[baseline,lines,
AspectRatio->9/80,PlotRange->{{0,Pi},{-0.13,0.25}}]\
\>", "Input",
 PageWidth:>WindowWidth,
 AspectRatioFixed->True,
 CellLabel->"In[27]:=",ExpressionUUID->"979b0a00-feee-46d4-bf11-97cfcd6071f0"],

Cell[BoxData[
 GraphicsBox[{
   LineBox[NCache[{{0, -0.125}, {Pi, -0.125}}, {{0, -0.125}, {
      3.141592653589793, -0.125}}]], {
    LineBox[{{0.024249452200854282`, 0}, {0.024249452200854282`, 0.25}}], 
    LineBox[{{0.02954072903421532, 0}, {0.02954072903421532, 0.25}}], 
    LineBox[{{0.04265186228496171, 0}, {0.04265186228496171, 0.25}}], 
    LineBox[{{0.06850181863459409, 0}, {0.06850181863459409, 0.25}}], 
    LineBox[{{0.13750333234729623`, 0}, {0.13750333234729623`, 0.25}}], 
    LineBox[{{0.1468863686340724, 0}, {0.1468863686340724, 0.25}}], 
    LineBox[{{0.37418677393762095`, 0}, {0.37418677393762095`, 0.25}}], 
    LineBox[{{0.7549794324997997, 0}, {0.7549794324997997, 0.25}}], 
    LineBox[{{0.9039893954053883, 0}, {0.9039893954053883, 0.25}}], 
    LineBox[{{1.1944679009867638`, 0}, {1.1944679009867638`, 0.25}}], 
    LineBox[{{1.5926439010800586`, 0}, {1.5926439010800586`, 0.25}}], 
    LineBox[{{1.7408615293233638`, 0}, {1.7408615293233638`, 0.25}}], 
    LineBox[{{1.8225982012391673`, 0}, {1.8225982012391673`, 0.25}}], 
    LineBox[{{1.9423584043075266`, 0}, {1.9423584043075266`, 0.25}}], 
    LineBox[{{2.2051349954151385`, 0}, {2.2051349954151385`, 0.25}}], 
    LineBox[{{2.2928419469409067`, 0}, {2.2928419469409067`, 0.25}}], 
    LineBox[{{2.2928615219382844`, 0}, {2.2928615219382844`, 0.25}}], 
    LineBox[{{2.6880126982260353`, 0}, {2.6880126982260353`, 0.25}}], 
    LineBox[{{3.0956084066030183`, 0}, {3.0956084066030183`, 0.25}}]}},
  AspectRatio->NCache[
    Rational[9, 80], 0.1125],
  PlotRange->
   NCache[{{0, Pi}, {-0.13, 0.25}}, {{0, 3.141592653589793}, {-0.13, 
     0.25}}]]], "Output",
 CellChangeTimes->{3.811158911297426*^9, 3.81116068845065*^9, 
  3.811160809545766*^9},
 CellLabel->"Out[27]=",ExpressionUUID->"a6b5a99e-2d60-4288-8676-05e32ff9633e"]
}, Open  ]],

Cell["... and the close-up of the region in the range 0 to 0.15.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"32eaa82d-2227-4693-8a00-15b6777e5487"],

Cell[CellGroupData[{

Cell["\<\
Show[baseline,lines,
AspectRatio->9/80, PlotRange->{{0,0.15},{-0.13,0.25}}]\
\>", "Input",
 CellLabel->"In[28]:=",ExpressionUUID->"1e13ea55-dc30-4b60-8ad2-59f42abdfd23"],

Cell[BoxData[
 GraphicsBox[{
   LineBox[NCache[{{0, -0.125}, {Pi, -0.125}}, {{0, -0.125}, {
      3.141592653589793, -0.125}}]], {
    LineBox[{{0.024249452200854282`, 0}, {0.024249452200854282`, 0.25}}], 
    LineBox[{{0.02954072903421532, 0}, {0.02954072903421532, 0.25}}], 
    LineBox[{{0.04265186228496171, 0}, {0.04265186228496171, 0.25}}], 
    LineBox[{{0.06850181863459409, 0}, {0.06850181863459409, 0.25}}], 
    LineBox[{{0.13750333234729623`, 0}, {0.13750333234729623`, 0.25}}], 
    LineBox[{{0.1468863686340724, 0}, {0.1468863686340724, 0.25}}], 
    LineBox[{{0.37418677393762095`, 0}, {0.37418677393762095`, 0.25}}], 
    LineBox[{{0.7549794324997997, 0}, {0.7549794324997997, 0.25}}], 
    LineBox[{{0.9039893954053883, 0}, {0.9039893954053883, 0.25}}], 
    LineBox[{{1.1944679009867638`, 0}, {1.1944679009867638`, 0.25}}], 
    LineBox[{{1.5926439010800586`, 0}, {1.5926439010800586`, 0.25}}], 
    LineBox[{{1.7408615293233638`, 0}, {1.7408615293233638`, 0.25}}], 
    LineBox[{{1.8225982012391673`, 0}, {1.8225982012391673`, 0.25}}], 
    LineBox[{{1.9423584043075266`, 0}, {1.9423584043075266`, 0.25}}], 
    LineBox[{{2.2051349954151385`, 0}, {2.2051349954151385`, 0.25}}], 
    LineBox[{{2.2928419469409067`, 0}, {2.2928419469409067`, 0.25}}], 
    LineBox[{{2.2928615219382844`, 0}, {2.2928615219382844`, 0.25}}], 
    LineBox[{{2.6880126982260353`, 0}, {2.6880126982260353`, 0.25}}], 
    LineBox[{{3.0956084066030183`, 0}, {3.0956084066030183`, 0.25}}]}},
  AspectRatio->NCache[
    Rational[9, 80], 0.1125],
  PlotRange->{{0, 0.15}, {-0.13, 0.25}}]], "Output",
 CellChangeTimes->{3.811158911352686*^9, 3.811160693014024*^9, 
  3.811160809553302*^9},
 CellLabel->"Out[28]=",ExpressionUUID->"57346503-50b3-44e1-bcb3-d2fe9df74cd7"]
}, Open  ]]
},
PrintingStyleEnvironment->"Printout",
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{920, 877},
WindowMargins->{{19, Automatic}, {Automatic, 103}},
PrintingCopies->1,
PrintingPageRange->{2, 2},
PageHeaders->{{
   Cell[
    TextData[{
      CounterBox["Page"]}], "PageNumber"], Inherited, 
   Cell[
    TextData[{
      ValueBox["FileName"]}], "Header"]}, {
   Cell[
    TextData[{
      ValueBox["FileName"]}], "Header"], Inherited, 
   Cell[
    TextData[{
      CounterBox["Page"]}], "PageNumber"]}},
PrintingOptions->{"PrintCellBrackets"->False,
"PrintMultipleHorizontalPages"->False,
"PrintRegistrationMarks"->True,
"PrintingMargins"->{{54, 54}, {72, 72}}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowCellLabel->True,
ShowCellTags->False,
FrontEndVersion->"12.1 for Mac OS X x86 (64-bit) (June 19, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"932f0db9-1dbe-4bd4-9320-6ea98d7bb7d4"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 136, 2, 67, "Section",ExpressionUUID->"2e046fd1-02bf-471e-bed0-2aa608f175b2"],
Cell[697, 24, 329, 7, 72, "Text",ExpressionUUID->"2a07afad-9c27-4c77-9971-06fcbe97d0fa"],
Cell[1029, 33, 287, 8, 84, "Input",ExpressionUUID->"66fd2450-98bf-4d4e-bed2-892797d75ae0"],
Cell[1319, 43, 275, 6, 48, "Input",ExpressionUUID->"a706c228-4c86-4c49-bbde-2cb171c07558"],
Cell[1597, 51, 167, 3, 53, "Text",ExpressionUUID->"62d4b19b-7a6e-4f25-96a4-8590224392f7"],
Cell[1767, 56, 231, 7, 66, "Input",ExpressionUUID->"ae06e143-0605-481b-8e25-113929c3a0e3"],
Cell[2001, 65, 231, 6, 48, "Input",ExpressionUUID->"f0fe5fb2-21ec-4743-9ec8-2a1d0ca7357a"],
Cell[2235, 73, 154, 3, 53, "Text",ExpressionUUID->"01d63a53-4d49-4c57-9b24-6ef579cac1ed"],
Cell[2392, 78, 269, 7, 66, "Input",ExpressionUUID->"ba2ea064-311d-4297-ba35-05f9f7eebc56"],
Cell[2664, 87, 265, 6, 48, "Input",ExpressionUUID->"fd7605ee-b33e-45a5-acef-ae3b8463e4fb"],
Cell[2932, 95, 152, 3, 53, "Text",ExpressionUUID->"baa27e18-316d-48b7-890c-c790af2fc2a2"],
Cell[3087, 100, 225, 7, 66, "Input",ExpressionUUID->"4aa19074-229b-4c7e-ae4e-c15a78fb01e2"],
Cell[3315, 109, 231, 6, 48, "Input",ExpressionUUID->"bb428c6f-70f1-4692-9112-cd699b8d864d"],
Cell[3549, 117, 158, 3, 53, "Text",ExpressionUUID->"9de56b14-6c4d-4c95-9d03-d294beec690e"],
Cell[3710, 122, 186, 6, 48, "Input",ExpressionUUID->"0faeffc2-181a-4f6e-8391-bb1d7987d08f"],
Cell[3899, 130, 186, 3, 30, "Input",ExpressionUUID->"eb869435-4f7b-4c8e-bc0d-3c0c8f74e223"],
Cell[4088, 135, 742, 21, 84, "Text",ExpressionUUID->"34cdcecf-a898-488c-b050-9d5221c166e0"],
Cell[CellGroupData[{
Cell[4855, 160, 191, 3, 49, "Input",ExpressionUUID->"e6b02b7f-38c8-4880-a4e4-d5b4f8a5dc1b"],
Cell[5049, 165, 3639, 106, 432, "Output",ExpressionUUID->"7f6ad3c5-4922-4724-a913-d752b770f1ca"]
}, Open  ]],
Cell[8703, 274, 964, 32, 147, "Text",ExpressionUUID->"ff33bb00-2d91-4ec1-84eb-8e57445efdbd"],
Cell[9670, 308, 1898, 54, 242, "Input",ExpressionUUID->"63b2dee2-1a80-4acf-8b64-837a38ea3ce3"],
Cell[11571, 364, 213, 6, 67, "Text",ExpressionUUID->"ea7134eb-b4e9-4cee-bbac-161cb3ff335f"],
Cell[CellGroupData[{
Cell[11809, 374, 235, 5, 49, "Input",ExpressionUUID->"091e7ab0-e695-4395-af2e-f1bd302830cc"],
Cell[12047, 381, 721, 18, 82, "Output",ExpressionUUID->"eb44f92f-9cad-4920-86a8-9f81143c6e1e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12805, 404, 180, 3, 49, "Input",ExpressionUUID->"12dbef65-1043-4ca6-8c56-45dee671534c"],
Cell[12988, 409, 609, 15, 82, "Output",ExpressionUUID->"b054f0aa-0633-4320-abf5-1c6be6ddcfc5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13634, 429, 178, 3, 49, "Input",ExpressionUUID->"b4e1a9e0-9fa7-48eb-b2fd-89bb4e956a84"],
Cell[13815, 434, 1173, 29, 146, "Output",ExpressionUUID->"de27dfbd-ae18-4647-ba6b-b5502f5f92e9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15025, 468, 178, 3, 49, "Input",ExpressionUUID->"82abcbb4-d4b6-4463-86d7-01389f35a3d3"],
Cell[15206, 473, 703, 17, 82, "Output",ExpressionUUID->"4c41aea0-1c7b-45e5-9090-2862c2a7cc5e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15946, 495, 180, 3, 49, "Input",ExpressionUUID->"2b2963a8-4f20-4084-9858-22b0e9d26e10"],
Cell[16129, 500, 215, 4, 49, "Output",ExpressionUUID->"4b15edb5-1d9e-489e-ad59-fbb90da640b2"]
}, Open  ]],
Cell[16359, 507, 624, 14, 131, "Text",ExpressionUUID->"61b0fe8b-dc67-4ad3-bbe4-20ee61d6f564"],
Cell[16986, 523, 521, 20, 465, "Input",ExpressionUUID->"6f8e7244-168c-4154-866f-7d554694c83c"],
Cell[17510, 545, 438, 12, 99, "Text",ExpressionUUID->"d5793148-6430-41d8-b67d-f17b1284f382"],
Cell[17951, 559, 519, 16, 335, "Input",ExpressionUUID->"d6100c74-ec82-4c2d-8524-4996f6f2b59d"],
Cell[18473, 577, 308, 9, 99, "Text",ExpressionUUID->"13de1944-42c1-444f-ac66-7421f41ce1e8"],
Cell[CellGroupData[{
Cell[18806, 590, 207, 4, 49, "Input",ExpressionUUID->"4e36306e-f95a-47e7-ba2e-671f2ff82360"],
Cell[19016, 596, 1320, 37, 224, "Output",ExpressionUUID->"5a783ee5-1245-4aea-879c-f1e8d2998328"]
}, Open  ]],
Cell[20351, 636, 205, 5, 67, "Text",ExpressionUUID->"b465bd8e-819c-4c87-985c-1df8e2fb313b"],
Cell[CellGroupData[{
Cell[20581, 645, 290, 8, 127, "Input",ExpressionUUID->"0424cd75-bcb0-49db-82b1-0dc90fe2de0c"],
Cell[20874, 655, 5510, 157, 1004, "Output",ExpressionUUID->"a6908933-d9bf-4eed-8836-c567b60eb6ad"]
}, Open  ]],
Cell[26399, 815, 234, 8, 67, "Text",ExpressionUUID->"54c9009d-4447-40a6-b051-bc3b4b875f66"],
Cell[CellGroupData[{
Cell[26658, 827, 515, 15, 49, "Input",ExpressionUUID->"640fc8ac-961b-4b7d-86de-9ce1c124c8fc"],
Cell[27176, 844, 5510, 157, 1004, "Output",ExpressionUUID->"8f5af721-c96d-4be6-9479-356af0403c7a"]
}, Open  ]],
Cell[32701, 1004, 213, 8, 67, "Text",ExpressionUUID->"9271d47b-b849-43f1-bcc4-cf5d6e3d9ce5"],
Cell[CellGroupData[{
Cell[32939, 1016, 263, 6, 49, "Input",ExpressionUUID->"877d84d1-237b-49b1-bbcb-47bc3f789c29"],
Cell[33205, 1024, 1011, 19, 146, "Output",ExpressionUUID->"225d17bb-f494-4751-a6f1-ce017a41833a"]
}, Open  ]],
Cell[34231, 1046, 164, 3, 67, "Text",ExpressionUUID->"9d868743-e874-41ce-a45a-24131341987c"],
Cell[CellGroupData[{
Cell[34420, 1053, 196, 4, 49, "Input",ExpressionUUID->"09847513-793f-407b-9caa-e04c7749535a"],
Cell[34619, 1059, 196, 3, 49, "Output",ExpressionUUID->"4163bcc5-dcff-4f5c-97d5-1dc3a785ca7d"]
}, Open  ]],
Cell[34830, 1065, 170, 3, 67, "Text",ExpressionUUID->"56fe806a-458f-401d-8231-4d37a4506c66"],
Cell[35003, 1070, 198, 3, 49, "Input",ExpressionUUID->"333faf9f-ae10-49d7-9c2b-87df0a655ab3"],
Cell[35204, 1075, 175, 3, 67, "Text",ExpressionUUID->"74791009-e54c-4e79-ad1b-ae570cc9fcc6"],
Cell[35382, 1080, 199, 3, 49, "Input",ExpressionUUID->"3b78f164-12a2-48fe-8d97-cd73b2c77d9a"],
Cell[35584, 1085, 155, 3, 67, "Text",ExpressionUUID->"b07fc449-74a2-47f3-b40c-3ec7bd5ff57e"],
Cell[CellGroupData[{
Cell[35764, 1092, 226, 6, 48, "Input",ExpressionUUID->"979b0a00-feee-46d4-bf11-97cfcd6071f0"],
Cell[35993, 1100, 1812, 30, 58, "Output",ExpressionUUID->"a6b5a99e-2d60-4288-8676-05e32ff9633e"]
}, Open  ]],
Cell[37820, 1133, 184, 3, 53, "Text",ExpressionUUID->"32eaa82d-2227-4693-8a00-15b6777e5487"],
Cell[CellGroupData[{
Cell[38029, 1140, 179, 4, 48, "Input",ExpressionUUID->"1e13ea55-dc30-4b60-8ad2-59f42abdfd23"],
Cell[38211, 1146, 1756, 28, 57, "Output",ExpressionUUID->"57346503-50b3-44e1-bcb3-d2fe9df74cd7"]
}, Open  ]]
}
]
*)

